@@ -5,7 +5,6 @@ from typing import ClassVar
 from rest_framework.permissions import BasePermission
 
 from openedx_authz import api
-from openedx_authz.engine.enforcer import AuthzEnforcer
 
 
 class PermissionMeta(type(BasePermission)):
@@ -183,7 +182,6 @@ class DynamicScopePermission(BaseScopePermission):
         """
         if request.user.is_superuser or request.user.is_staff:
             return True
-        AuthzEnforcer.get_enforcer().load_policy()
         return self._get_permission_instance(request).has_permission(request, view)
 
     def has_object_permission(self, request, view, obj) -> bool:
@@ -200,7 +198,6 @@ class DynamicScopePermission(BaseScopePermission):
         """
         if request.user.is_superuser or request.user.is_staff:
             return True
-        AuthzEnforcer.get_enforcer().load_policy()
         return self._get_permission_instance(request).has_object_permission(request, view, obj)
 
 
@@ -221,7 +218,7 @@ class MethodPermissionMixin:
         >>> class MyView(APIView):
         ...     permission_classes = [MyPermission]
         ...
-        ...     @authz_permissions(["view_library_team"])
+        ...     @authz_permissions(["content_libraries.view_library_team"])
         ...     def get(self, request):
         ...         pass
     """
