@@ -16,7 +16,6 @@ from rest_framework.views import APIView
 
 from openedx_authz import api
 from openedx_authz.constants import permissions
-from openedx_authz.engine.enforcer import AuthzEnforcer
 from openedx_authz.rest_api.data import RoleOperationError, RoleOperationStatus
 from openedx_authz.rest_api.decorators import authz_permissions, view_auth_classes
 from openedx_authz.rest_api.utils import (
@@ -61,7 +60,7 @@ class PermissionValidationMeView(APIView):
 
     Expects a list of permission objects, each containing:
 
-    - action: The action to validate (e.g., 'edit_library', 'delete_library_content')
+    - action: The action to validate (e.g., 'content_libraries.edit_library_content')
     - scope: The authorization scope (e.g., 'lib:DemoX:CSPROB')
 
     **Response Format**
@@ -103,7 +102,6 @@ class PermissionValidationMeView(APIView):
     )
     def post(self, request: HttpRequest) -> Response:
         """Validate one or more permissions for the authenticated user."""
-        AuthzEnforcer.get_enforcer().load_policy()
 
         serializer = PermissionValidationSerializer(data=request.data, many=True)
         serializer.is_valid(raise_exception=True)
@@ -379,7 +377,7 @@ class RoleListView(APIView):
     Returns a paginated list of role objects, each containing:
 
     - role: The role's external identifier (e.g., 'library_author', 'library_user')
-    - permissions: List of permission action keys granted by this role (e.g., 'delete_library_content')
+    - permissions: List of permission identifiers granted by this role (e.g., 'content_libraries.delete_library')
     - user_count: Number of users currently assigned to this role
 
     **Authentication and Permissions**
