@@ -5,8 +5,10 @@ including role creation, assignment, permission management, and querying
 roles and permissions within specific scopes.
 """
 
+from importlib.resources import files
+from unittest.mock import patch
+
 import casbin
-import pkg_resources
 from ddt import data as ddt_data
 from ddt import ddt, unpack
 from django.test import TestCase
@@ -33,8 +35,9 @@ from openedx_authz.api.roles import (
     get_subject_role_assignments_in_scope,
     get_subjects_for_role_in_scope,
     unassign_role_from_subject_in_scope,
+    unassign_subject_from_all_roles,
 )
-from openedx_authz.constants import roles
+from openedx_authz.constants import permissions, roles
 from openedx_authz.constants.roles import (
     LIBRARY_ADMIN_PERMISSIONS,
     LIBRARY_AUTHOR_PERMISSIONS,
@@ -43,6 +46,32 @@ from openedx_authz.constants.roles import (
 )
 from openedx_authz.engine.enforcer import AuthzEnforcer
 from openedx_authz.engine.utils import migrate_policy_between_enforcers
+from openedx_authz.models import ExtendedCasbinRule, Scope, Subject
+
+
+def _mock_get_or_create_scope(scope_data):
+    """Mock implementation that creates actual Scope instances."""
+    scope, _ = Scope.objects.get_or_create(id=hash(scope_data.external_key) % 10000)
+    return scope
+
+
+def _mock_get_or_create_subject(subject_data):
+    """Mock implementation that creates actual Subject instances."""
+    subject, _ = Subject.objects.get_or_create(id=hash(subject_data.external_key) % 10000)
+    return subject
+
+
+# Apply patches at module level using the new manager method
+_scope_patcher = patch(
+    "openedx_authz.models.ScopeManager.get_or_create_for_external_key",
+    side_effect=_mock_get_or_create_scope,
+)
+_subject_patcher = patch(
+    "openedx_authz.models.SubjectManager.get_or_create_for_external_key",
+    side_effect=_mock_get_or_create_subject,
+)
+_scope_patcher.start()
+_subject_patcher.start()
 
 
 class BaseRolesTestCase(TestCase):
@@ -62,8 +91,8 @@ class BaseRolesTestCase(TestCase):
         """
         global_enforcer = AuthzEnforcer.get_enforcer()
         global_enforcer.load_policy()
-        model_path = pkg_resources.resource_filename("openedx_authz.engine", "config/model.conf")
-        policy_path = pkg_resources.resource_filename("openedx_authz.engine", "config/authz.policy")
+        model_path = str(files("openedx_authz.engine").joinpath("config/model.conf"))
+        policy_path = str(files("openedx_authz.engine").joinpath("config/authz.policy"))
 
         migrate_policy_between_enforcers(
             source_enforcer=casbin.Enforcer(model_path, policy_path),
@@ -277,6 +306,50 @@ class TestRolesAPI(RolesTestSetupMixin):
     environments.
     """
 
+    def test_assign_role_creates_extended_rule(self):
+        """Assign a role to a subject and verify an ExtendedCasbinRule is created.
+
+        Expected result:
+            - The assignment function returns True
+            - An ExtendedCasbinRule record exists linking the subject and scope
+        """
+
+        subject = SubjectData(external_key="unit_test_user_assign_1")
+        role = RoleData(external_key="library_user")
+        scope = ScopeData(external_key="lib:UnitTest:assign_lib_1")
+
+        subj_before = Subject.objects.get_or_create_for_external_key(subject)
+        scope_before = Scope.objects.get_or_create_for_external_key(scope)
+        self.assertFalse(ExtendedCasbinRule.objects.filter(subject=subj_before, scope=scope_before).exists())
+
+        result = assign_role_to_subject_in_scope(subject, role, scope)
+        self.assertTrue(result)
+
+        subj_obj = Subject.objects.get_or_create_for_external_key(subject)
+        scope_obj = Scope.objects.get_or_create_for_external_key(scope)
+        self.assertTrue(ExtendedCasbinRule.objects.filter(subject=subj_obj, scope=scope_obj).exists())
+
+    def test_assign_role_fails_when_extended_rule_not_created(self):
+        """Test that assign_role raises exception when ExtendedCasbinRule creation fails.
+
+        Expected result:
+            - Exception is raised when ExtendedCasbinRule.create_based_on_policy returns None
+            - Transaction is rolled back and no role assignment persists
+        """
+        subject = SubjectData(external_key="unit_test_user_assign_fail")
+        role = RoleData(external_key="library_user")
+        scope = ScopeData(external_key="lib:UnitTest:assign_fail_lib")
+
+        with patch("openedx_authz.models.ExtendedCasbinRule.create_based_on_policy", return_value=None):
+            with self.assertRaises(Exception) as context:
+                assign_role_to_subject_in_scope(subject, role, scope)
+
+            self.assertEqual(str(context.exception), "Failed to create ExtendedCasbinRule for the assignment")
+
+            subj_obj = Subject.objects.get_or_create_for_external_key(subject)
+            scope_obj = Scope.objects.get_or_create_for_external_key(scope)
+            self.assertFalse(ExtendedCasbinRule.objects.filter(subject=subj_obj, scope=scope_obj).exists())
+
     @ddt_data(
         # Library Admin role with actual permissions from authz.policy
         (
@@ -521,73 +594,73 @@ class TestRolesAPI(RolesTestSetupMixin):
         # Test case: alice with 'view_library' permission (has library_admin in math_101)
         (
             "alice",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             ["lib:Org1:math_101"],
         ),
         # Test case: alice with 'publish_library_content' permission (admin grants publish)
         (
             "alice",
-            "publish_library_content",
+            permissions.PUBLISH_LIBRARY_CONTENT.identifier,
             ["lib:Org1:math_101"],
         ),
         # Test case: alice with 'delete_library' permission (admin grants delete)
         (
             "alice",
-            "delete_library",
+            permissions.DELETE_LIBRARY.identifier,
             ["lib:Org1:math_101"],
         ),
         # Test case: bob with 'view_library' permission (has library_author in history_201)
         (
             "bob",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             ["lib:Org1:history_201"],
         ),
         # Test case: bob with 'publish_library_content' permission (author grants publish)
         (
             "bob",
-            "publish_library_content",
+            permissions.PUBLISH_LIBRARY_CONTENT.identifier,
             ["lib:Org1:history_201"],
         ),
         # Test case: bob with 'delete_library' permission (author does NOT grant delete)
         (
             "bob",
-            "delete_library",
+            permissions.DELETE_LIBRARY.identifier,
             [],
         ),
         # Test case: carol with 'view_library' permission (has library_contributor in science_301)
         (
             "carol",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             ["lib:Org1:science_301"],
         ),
         # Test case: carol with 'publish_library_content' permission (contributor does NOT grant publish)
         (
             "carol",
-            "publish_library_content",
+            permissions.PUBLISH_LIBRARY_CONTENT.identifier,
             [],
         ),
         # Test case: dave with 'view_library' permission (has library_user in english_101)
         (
             "dave",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             ["lib:Org1:english_101"],
         ),
         # Test case: dave with 'publish_library_content' permission (user does NOT grant publish)
         (
             "dave",
-            "publish_library_content",
+            permissions.PUBLISH_LIBRARY_CONTENT.identifier,
             [],
         ),
         # Test case: liam with 'view_library' permission (has library_author in 3 art libraries)
         (
             "liam",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             ["lib:Org4:art_101", "lib:Org4:art_201", "lib:Org4:art_301"],
         ),
         # Test case: non-existent user
         (
             "nonexistent",
-            "view_library",
+            permissions.VIEW_LIBRARY.identifier,
             [],
         ),
     )
@@ -646,7 +719,7 @@ class TestRolesAPI(RolesTestSetupMixin):
         )
 
         subject = SubjectData(external_key=test_subject)
-        permission = PermissionData(action=ActionData(external_key="view_library"))
+        permission = PermissionData(action=ActionData(external_key=permissions.VIEW_LIBRARY.identifier))
 
         scopes = get_scopes_for_subject_and_permission(subject, permission)
         scope_external_keys = [scope.external_key for scope in scopes]
@@ -877,3 +950,182 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
         self.assertEqual(len(role_assignments), len(expected_assignments))
         for assignment in role_assignments:
             self.assertIn(assignment, expected_assignments)
+
+    def test_assign_role_creates_extended_casbin_rule(self):
+        """Test that assigning a role creates an ExtendedCasbinRule record.
+
+        Expected result:
+            - After assigning a role, an ExtendedCasbinRule is created
+            - The ExtendedCasbinRule has the correct subject and scope references
+            - The ExtendedCasbinRule is linked to a CasbinRule
+        """
+        initial_count = ExtendedCasbinRule.objects.count()
+        subject_data = SubjectData(external_key="test_user_extended")
+        role_data = RoleData(external_key=roles.LIBRARY_USER.external_key)
+        scope_data = ScopeData(external_key="lib:TestOrg:TestLib")
+
+        assign_role_to_subject_in_scope(subject_data, role_data, scope_data)
+
+        new_count = ExtendedCasbinRule.objects.count()
+        self.assertEqual(new_count, initial_count + 1)
+
+        extended_rule = ExtendedCasbinRule.objects.order_by("-id").first()
+        self.assertIsNotNone(extended_rule)
+        self.assertIsNotNone(extended_rule.casbin_rule)
+        self.assertIsNotNone(extended_rule.subject)
+        self.assertIsNotNone(extended_rule.scope)
+        self.assertIn(role_data.namespaced_key, extended_rule.casbin_rule_key)
+        self.assertIn(subject_data.namespaced_key, extended_rule.casbin_rule_key)
+        self.assertIn(scope_data.namespaced_key, extended_rule.casbin_rule_key)
+
+    @ddt_data(
+        # Test user with single role in single scope
+        ("alice", ["lib:Org1:math_101"], {"library_admin"}),
+        # Test user with multiple roles in different scopes
+        (
+            "eve",
+            ["lib:Org2:physics_401", "lib:Org2:chemistry_501", "lib:Org2:biology_601"],
+            {"library_admin", "library_author", "library_user"},
+        ),
+        # Test user with same role in multiple scopes
+        ("liam", ["lib:Org4:art_101", "lib:Org4:art_201", "lib:Org4:art_301"], {"library_author"}),
+        # Test user with multiple different roles in multiple scopes
+        (
+            "peter",
+            ["lib:Org6:project_alpha", "lib:Org6:project_beta", "lib:Org6:project_gamma", "lib:Org6:project_delta"],
+            {"library_admin", "library_author", "library_contributor", "library_user"},
+        ),
+    )
+    @unpack
+    def test_unassign_subject_from_all_roles_removes_all_assignments(self, subject_name, scopes, expected_roles_before):
+        """Test that unassign_subject_from_all_roles removes all role assignments.
+
+        Expected result:
+            - Before unassignment: Subject has roles in specified scopes
+            - Function returns True indicating roles were removed
+            - After unassignment: Subject has no role assignments in any scope
+            - Querying role assignments returns empty list
+        """
+        subject = SubjectData(external_key=subject_name)
+
+        # Verify the subject has roles before unassignment
+        assignments_before = get_subject_role_assignments(subject)
+        self.assertGreater(len(assignments_before), 0)
+
+        # Verify roles are what we expect before removal
+        roles_before = {r.external_key for assignment in assignments_before for r in assignment.roles}
+        self.assertEqual(roles_before, expected_roles_before)
+
+        # Verify assignments exist in each expected scope
+        for scope_name in scopes:
+            scope_assignments = get_subject_role_assignments_in_scope(subject, ScopeData(external_key=scope_name))
+            self.assertGreater(len(scope_assignments), 0)
+
+        # Unassign all roles from the subject
+        result = unassign_subject_from_all_roles(subject)
+
+        # Verify the function returns True (indicating roles were removed)
+        self.assertTrue(result)
+
+        # Verify the subject has no role assignments after unassignment
+        assignments_after = get_subject_role_assignments(subject)
+        self.assertEqual(len(assignments_after), 0)
+
+        # Verify no assignments in any of the previous scopes
+        for scope_name in scopes:
+            scope_assignments = get_subject_role_assignments_in_scope(subject, ScopeData(external_key=scope_name))
+            self.assertEqual(len(scope_assignments), 0)
+
+    def test_unassign_subject_with_no_roles_returns_false(self):
+        """Test that unassigning a subject with no roles returns False.
+
+        Expected result:
+            - Function returns False when subject has no role assignments
+            - No errors occur when trying to unassign from non-existent subject
+        """
+        non_existent_subject = SubjectData(external_key="user_with_no_roles")
+
+        # Verify the subject has no roles
+        assignments_before = get_subject_role_assignments(non_existent_subject)
+        self.assertEqual(len(assignments_before), 0)
+
+        # Unassign all roles (should return False since there are none)
+        result = unassign_subject_from_all_roles(non_existent_subject)
+
+        # Verify the function returns False (no roles to remove)
+        self.assertFalse(result)
+
+        # Verify still no assignments after the operation
+        assignments_after = get_subject_role_assignments(non_existent_subject)
+        self.assertEqual(len(assignments_after), 0)
+
+    def test_unassign_subject_does_not_affect_other_subjects(self):
+        """Test that unassigning one subject does not affect other subjects.
+
+        Expected result:
+            - When unassigning roles from one subject, other subjects retain their roles
+            - Other subjects with the same roles in the same scopes are unaffected
+        """
+        # Use subjects that share the same scope
+        subject_to_unassign = SubjectData(external_key="grace")
+        other_subject = SubjectData(external_key="heidi")
+        shared_scope = ScopeData(external_key="lib:Org1:math_advanced")
+
+        # Verify both subjects have roles in the shared scope before
+        grace_assignments_before = get_subject_role_assignments_in_scope(subject_to_unassign, shared_scope)
+        heidi_assignments_before = get_subject_role_assignments_in_scope(other_subject, shared_scope)
+
+        self.assertGreater(len(grace_assignments_before), 0)
+        self.assertGreater(len(heidi_assignments_before), 0)
+
+        # Unassign all roles from grace
+        result = unassign_subject_from_all_roles(subject_to_unassign)
+        self.assertTrue(result)
+
+        # Verify grace has no assignments after unassignment
+        grace_assignments_after = get_subject_role_assignments(subject_to_unassign)
+        self.assertEqual(len(grace_assignments_after), 0)
+
+        # Verify heidi still has her assignments
+        heidi_assignments_after = get_subject_role_assignments_in_scope(other_subject, shared_scope)
+        self.assertEqual(len(heidi_assignments_after), len(heidi_assignments_before))
+
+        # Verify heidi still has the library_contributor role
+        heidi_roles = {r.external_key for assignment in heidi_assignments_after for r in assignment.roles}
+        self.assertIn("library_contributor", heidi_roles)
+
+    def test_unassign_and_reassign_subject(self):
+        """Test that a subject can be reassigned roles after being unassigned.
+
+        Expected result:
+            - Subject has roles initially
+            - After unassignment, subject has no roles
+            - Subject can be assigned new roles
+            - Newly assigned roles work correctly
+        """
+        subject = SubjectData(external_key="bob")
+        new_scope = ScopeData(external_key="lib:Org1:new_library")
+        new_role = RoleData(external_key="library_admin")
+
+        # Verify bob has roles initially
+        assignments_before = get_subject_role_assignments(subject)
+        self.assertGreater(len(assignments_before), 0)
+
+        # Unassign all roles
+        result = unassign_subject_from_all_roles(subject)
+        self.assertTrue(result)
+
+        # Verify no roles after unassignment
+        assignments_after_unassign = get_subject_role_assignments(subject)
+        self.assertEqual(len(assignments_after_unassign), 0)
+
+        # Assign a new role in a new scope
+        assign_result = assign_role_to_subject_in_scope(subject, new_role, new_scope)
+        self.assertTrue(assign_result)
+
+        # Verify the new assignment works
+        new_assignments = get_subject_role_assignments_in_scope(subject, new_scope)
+        self.assertEqual(len(new_assignments), 1)
+
+        new_roles = {r.external_key for assignment in new_assignments for r in assignment.roles}
+        self.assertIn("library_admin", new_roles)
