@@ -127,13 +127,19 @@ class ViewTestMixin(BaseRolesTestCase):
     def create_regular_users(cls, quantity: int):
         """Create regular users."""
         for i in range(1, quantity + 1):
-            User.objects.create_user(username=f"regular_{i}", email=f"regular_{i}@example.com")
+            User.objects.get_or_create(username=f"regular_{i}", defaults={"email": f"regular_{i}@example.com"})
 
     @classmethod
     def create_admin_users(cls, quantity: int):
         """Create admin users."""
         for i in range(1, quantity + 1):
-            User.objects.create_superuser(username=f"admin_{i}", email=f"admin_{i}@example.com")
+            user, created = User.objects.get_or_create(
+                username=f"admin_{i}", defaults={"email": f"admin_{i}@example.com"}
+            )
+            if created:
+                user.is_superuser = True
+                user.is_staff = True
+                user.save()
 
     @classmethod
     def setUpTestData(cls):
@@ -166,13 +172,13 @@ class TestPermissionValidationMeView(ViewTestMixin):
         # Single permission - denied (scope not assigned to user)
         ([{"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org2:LIB2"}], [False]),
         # Single permission - denied (action not assigned to user)
-        ([{"action": "edit_library", "scope": "lib:Org1:LIB1"}], [False]),
+        ([{"action": "content_libraries.edit_library", "scope": "lib:Org1:LIB1"}], [False]),
         # Multiple permissions - mixed results
         (
             [
                 {"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org1:LIB1"},
                 {"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org2:LIB2"},
-                {"action": "edit_library", "scope": "lib:Org1:LIB1"},
+                {"action": "content_libraries.edit_library", "scope": "lib:Org1:LIB1"},
             ],
             [True, False, False],
         ),
@@ -195,6 +201,36 @@ class TestPermissionValidationMeView(ViewTestMixin):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data, expected_response)
 
+    @data(
+        ("lib:AnyOrg1:ANYLIB1", True),
+        ("lib:AnyOrg2:ANYLIB2", True),
+        ("lib:AnyOrg3:ANYLIB3", True),
+        ("global:AnyScope1", False),
+    )
+    @unpack
+    def test_permission_validation_staff_superuser_access(self, scope: str, expected_result: bool):
+        """Test that staff/superuser users have guaranteed permissions for ContentLibrary scopes.
+
+        Test cases:
+            - ContentLibrary scopes (lib:*): Staff/superuser automatically allowed
+            - Generic scopes (global:*): No automatic access granted
+
+        Expected result:
+            - Returns 200 OK status
+            - For library scopes: All permissions are allowed (True)
+            - For non-library scopes: Permissions follow normal authorization (False)
+        """
+        self.client.force_authenticate(user=self.admin_user)
+        request_data = [{"action": perm.identifier, "scope": scope} for perm in roles.LIBRARY_ADMIN_PERMISSIONS]
+        expected_response = request_data.copy()
+        for item in expected_response:
+            item["allowed"] = expected_result
+
+        response = self.client.post(self.url, data=request_data, format="json")
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.data, expected_response)
+
     @data(
         # Single permission
         [{"action": "edit_library"}],
